@@ -30,19 +30,20 @@
 #include "gui/widgets/setupwidget.h"
 #include "preferences.h"
 
-#include <KAction>
+#include <QAction>
 #include <KActionCollection>
 #include <KConfigDialog>
-#include <KFileDialog>
 #include <KNS3/DownloadDialog>
-#include <KStandardDirs>
 #include <KStandardGameAction>
 #include <KToggleAction>
-
+#include <QUrl>
+#include <QIcon>
+#include <KHelpClient>
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgamethemeselector.h>
 
 #include <QDockWidget>
+#include <QFileDialog>
 #include <QTimer>
 #include <QUndoView>
 
@@ -59,10 +60,10 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     setupGUI(QSize(800, 700), KXmlGuiWindow::ToolBar | KXmlGuiWindow::Keys |
                               KXmlGuiWindow::Save | KXmlGuiWindow::Create);
 
-    connect(m_game, SIGNAL(waiting(bool)), this, SLOT(showBusy(bool)));
-    connect(m_game, SIGNAL(consecutivePassMovesPlayed(int)), this, SLOT(showFinishGameAction()));
-    connect(m_game, SIGNAL(resigned(Player)), this, SLOT(finishGame()));
-    connect(m_game, SIGNAL(passMovePlayed(Player)), this, SLOT(passMovePlayed(Player)));
+    connect(m_game, &Game::waiting, this, &MainWindow::showBusy);
+    connect(m_game, &Game::consecutivePassMovesPlayed, this, &MainWindow::showFinishGameAction);
+    connect(m_game, &Game::resigned, this, &MainWindow::finishGame);
+    connect(m_game, &Game::passMovePlayed, this, &MainWindow::passMovePlayed);
 
     if (isBackendWorking()) {
         if (!loadGame(fileName)) {
@@ -91,9 +92,9 @@ void MainWindow::newGame()
     m_passMoveAction->setEnabled(false);
     m_hintAction->setEnabled(false);
 
-    disconnect(m_game, SIGNAL(canRedoChanged(bool)), m_redoMoveAction, SLOT(setEnabled(bool)));
-    disconnect(m_game, SIGNAL(canUndoChanged(bool)), m_undoMoveAction, SLOT(setEnabled(bool)));
-    disconnect(m_game, SIGNAL(currentPlayerChanged(Player)), this, SLOT(playerChanged()));
+    disconnect(m_game, &Game::canRedoChanged, m_redoMoveAction, &QAction::setEnabled);
+    disconnect(m_game, &Game::canUndoChanged, m_undoMoveAction, &QAction::setEnabled);
+    disconnect(m_game, &Game::currentPlayerChanged, this, &MainWindow::playerChanged);
 
     m_gameDock->setVisible(false);
     m_gameDock->toggleViewAction()->setEnabled(false);
@@ -103,12 +104,13 @@ void MainWindow::newGame()
     m_errorDock->setVisible(false);
 
     m_setupWidget->newGame();
-    m_gameScene->showMessage(i18n("Set up a new game..."));
+    QTimer::singleShot(0, this, [this] { m_gameScene->showMessage(i18n("Set up a new game...")); } );
 }
 
 void MainWindow::loadGame()
 {
-    QString fileName = KFileDialog::getOpenFileName(KUrl(KStandardDirs::locate("appdata", "games/")), "*.sgf");
+    const QString folderName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("games"), QStandardPaths::LocateDirectory);
+    const QString fileName = QFileDialog::getOpenFileName(this, QString(), folderName, i18n("Kigo Game Files (*.sgf)"));
     if (!fileName.isEmpty()) {
         loadGame(fileName);
     }
@@ -133,9 +135,9 @@ bool MainWindow::loadGame(const QString &fileName)
         m_passMoveAction->setEnabled(false);
         m_hintAction->setEnabled(false);
 
-        disconnect(m_game, SIGNAL(canRedoChanged(bool)), m_redoMoveAction, SLOT(setEnabled(bool)));
-        disconnect(m_game, SIGNAL(canUndoChanged(bool)), m_undoMoveAction, SLOT(setEnabled(bool)));
-        disconnect(m_game, SIGNAL(currentPlayerChanged(Player)), this, SLOT(playerChanged()));
+        disconnect(m_game, &Game::canRedoChanged, m_redoMoveAction, &QAction::setEnabled);
+        disconnect(m_game, &Game::canUndoChanged, m_undoMoveAction, &QAction::setEnabled);
+        disconnect(m_game, &Game::currentPlayerChanged, this, &MainWindow::playerChanged);
 
         m_gameDock->setVisible(false);
         m_gameDock->toggleViewAction()->setEnabled(false);
@@ -156,7 +158,7 @@ bool MainWindow::loadGame(const QString &fileName)
 
 void MainWindow::getMoreGames()
 {
-    KNS3::DownloadDialog dialog("kigo-games.knsrc", this);
+    KNS3::DownloadDialog dialog(QStringLiteral("kigo-games.knsrc"), this);
     dialog.exec();
 
     /*KNS3::Entry::List entries = dialog.changedEntries();
@@ -181,9 +183,9 @@ void MainWindow::backendError()
     m_passMoveAction->setEnabled(false);
     m_hintAction->setEnabled(false);
 
-    disconnect(m_game, SIGNAL(canRedoChanged(bool)), m_redoMoveAction, SLOT(setEnabled(bool)));
-    disconnect(m_game, SIGNAL(canUndoChanged(bool)), m_undoMoveAction, SLOT(setEnabled(bool)));
-    disconnect(m_game, SIGNAL(currentPlayerChanged(Player)), this, SLOT(playerChanged()));
+    disconnect(m_game, &Game::canRedoChanged, m_redoMoveAction, &QAction::setEnabled);
+    disconnect(m_game, &Game::canUndoChanged, m_undoMoveAction, &QAction::setEnabled);
+    disconnect(m_game, &Game::currentPlayerChanged, this, &MainWindow::playerChanged);
     m_gameDock->setVisible(false);
     m_gameDock->toggleViewAction()->setEnabled(false);
     m_movesDock->setVisible(false);
@@ -194,13 +196,14 @@ void MainWindow::backendError()
 
 void MainWindow::saveGame()
 {
-    QString fileName = KFileDialog::getSaveFileName(KUrl(QDir::homePath()), "*.sgf");
+    const QString fileName = QFileDialog::getSaveFileName(this, QString(), QStandardPaths::writableLocation(QStandardPaths::HomeLocation), i18n("Kigo Game Files (*.sgf)"));
 
     if (!fileName.isEmpty()) {
-        if (m_game->save(fileName))
+        if (m_game->save(fileName)) {
             m_gameScene->showMessage(i18n("Game saved..."));
-        else
+        } else {
             m_gameScene->showMessage(i18n("Unable to save game."));
+        }
     }
 }
 
@@ -214,8 +217,8 @@ void MainWindow::startGame()
 
     //Decide on players how to display the UI
     if (m_game->whitePlayer().isHuman() || m_game->blackPlayer().isHuman()) {
-        connect(m_game, SIGNAL(canRedoChanged(bool)), m_redoMoveAction, SLOT(setEnabled(bool)));
-        connect(m_game, SIGNAL(canUndoChanged(bool)), m_undoMoveAction, SLOT(setEnabled(bool)));
+        connect(m_game, &Game::canRedoChanged, m_redoMoveAction, &QAction::setEnabled);
+        connect(m_game, &Game::canUndoChanged, m_undoMoveAction, &QAction::setEnabled);
 
         m_passMoveAction->setEnabled(true);
         m_hintAction->setEnabled(true);
@@ -234,7 +237,7 @@ void MainWindow::startGame()
         m_gameScene->showPlacementMarker(false);
     }
 
-    connect(m_game, SIGNAL(currentPlayerChanged(Player)), this, SLOT(playerChanged()));
+    connect(m_game, &Game::currentPlayerChanged, this, &MainWindow::playerChanged);
     // Trigger the slot once to make a move if the starting player
     // (black) is a computer player.
     playerChanged();
@@ -267,7 +270,7 @@ void MainWindow::finishGame()
 
     m_undoView->setEnabled(false);
 
-    // kDebug() << "Fetching final score from engine ...";
+    //qDebug() << "Fetching final score from engine ...";
     Score score = m_game->estimatedScore();
     QString name;
     if (score.color() == 'W') {
@@ -304,8 +307,7 @@ void MainWindow::redo()
 
 void MainWindow::pass()
 {
-    if (m_game->playMove(m_game->currentPlayer())) {     // E.g. Pass move
-        //m_gameScene->showMessage(i18n("Passed move"));
+    if (m_game->playMove(m_game->currentPlayer())) { // E.g. Pass move
         m_gameScene->showHint(false);
     }
 }
@@ -313,25 +315,27 @@ void MainWindow::pass()
 void MainWindow::hint()
 {
     m_gameScene->showHint(true);
-    //m_gameScene->showMessage(i18n("These are the recommended moves..."));
 }
 
 void MainWindow::showPreferences()
 {
-    if (KConfigDialog::showDialog("settings"))
+    if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
         return;
+    }
 
-    KConfigDialog *dialog = new KConfigDialog(this, "settings", Preferences::self());
-    dialog->addPage(new GeneralConfig(), i18n("General"), "preferences-other");
-    dialog->addPage(new KGameThemeSelector(dialog, Preferences::self(), KGameThemeSelector::NewStuffDisableDownload), i18n("Themes"), "games-config-theme");
-    dialog->setHelp(QString(), "Kigo");
-    connect(dialog, SIGNAL(settingsChanged(QString)), this, SLOT(applyPreferences()));
+    KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), Preferences::self());
+    dialog->addPage(new GeneralConfig(), i18n("General"), QStringLiteral("preferences-other"));
+    dialog->addPage(new KGameThemeSelector(dialog, Preferences::self(), KGameThemeSelector::NewStuffDisableDownload), i18n("Themes"), QStringLiteral("games-config-theme"));
+    if (QPushButton *restore = dialog->button(QDialogButtonBox::RestoreDefaults)) {
+        restore->hide();
+    }
+    connect(dialog, &KConfigDialog::settingsChanged, this, &MainWindow::applyPreferences);
     dialog->show();
 }
 
 void MainWindow::applyPreferences()
 {
-    // kDebug() << "Update settings based on changed configuration...";
+    //qDebug() << "Update settings based on changed configuration...";
     m_gameScene->showLabels(Preferences::showBoardLabels());
 
     ThemeRenderer::self()->loadTheme(Preferences::theme());
@@ -377,7 +381,7 @@ void MainWindow::showFinishGameAction()
 void MainWindow::playerChanged()
 {
     if (!m_game->currentPlayer().isHuman() && !m_game->isFinished()) {
-        QTimer::singleShot(200, this, SLOT(generateMove()));
+        QTimer::singleShot(200, this, &MainWindow::generateMove);
     }
 }
 
@@ -402,40 +406,40 @@ void MainWindow::setupActions()
     // Game menu
     m_newGameAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
     m_loadGameAction = KStandardGameAction::load(this, SLOT(loadGame()), actionCollection());
-    m_getMoreGamesAction = new KAction(KIcon( QLatin1String( "get-hot-new-stuff") ), i18nc("@action", "Get More Games..." ), this);
-    m_getMoreGamesAction->setShortcut(Qt::CTRL + Qt::Key_G);
+    m_getMoreGamesAction = new QAction(QIcon::fromTheme( QStringLiteral( "get-hot-new-stuff") ), i18nc("@action", "Get More Games..." ), this);
+    actionCollection()->setDefaultShortcut(m_getMoreGamesAction, Qt::CTRL + Qt::Key_G);
     m_getMoreGamesAction->setToolTip(i18nc("@action", "Get More Games..."));
-    connect(m_getMoreGamesAction, SIGNAL(triggered(bool)), this, SLOT(getMoreGames()));
-    actionCollection()->addAction( QLatin1String( "get_more_games" ), m_getMoreGamesAction);
+    connect(m_getMoreGamesAction, &QAction::triggered, this, &MainWindow::getMoreGames);
+    actionCollection()->addAction( QStringLiteral( "get_more_games" ), m_getMoreGamesAction);
     m_saveAction = KStandardGameAction::save(this, SLOT(saveGame()), actionCollection());
     KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
-    m_startGameAction = new KAction(KIcon( QLatin1String( "media-playback-start") ), i18nc("@action", "Start Game" ), this);
-    m_startGameAction->setShortcut(Qt::Key_S);
+    m_startGameAction = new QAction(QIcon::fromTheme( QStringLiteral( "media-playback-start") ), i18nc("@action", "Start Game" ), this);
+    actionCollection()->setDefaultShortcut(m_startGameAction, Qt::Key_S);
     m_startGameAction->setToolTip(i18nc("@action", "Start Game"));
-    connect(m_startGameAction, SIGNAL(triggered(bool)), this, SLOT(startGame()));
-    actionCollection()->addAction( QLatin1String( "game_start" ), m_startGameAction);
+    connect(m_startGameAction, &QAction::triggered, this, &MainWindow::startGame);
+    actionCollection()->addAction( QStringLiteral( "game_start" ), m_startGameAction);
 
-    m_finishGameAction = new KAction(KIcon( QLatin1String( "media-playback-stop") ), i18nc("@action", "Finish Game" ), this);
-    m_finishGameAction->setShortcut(Qt::Key_F);
+    m_finishGameAction = new QAction(QIcon::fromTheme( QStringLiteral( "media-playback-stop") ), i18nc("@action", "Finish Game" ), this);
+    actionCollection()->setDefaultShortcut(m_finishGameAction,Qt::Key_F);
     m_finishGameAction->setToolTip(i18nc("@action", "Finish Game"));
-    connect(m_finishGameAction, SIGNAL(triggered(bool)), this, SLOT(finishGame()));
-    actionCollection()->addAction( QLatin1String( "game_finish" ), m_finishGameAction);
+    connect(m_finishGameAction, &QAction::triggered, this, &MainWindow::finishGame);
+    actionCollection()->addAction( QStringLiteral( "game_finish" ), m_finishGameAction);
 
     // Move menu
     m_undoMoveAction = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
     m_redoMoveAction = KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
     m_passMoveAction = KStandardGameAction::endTurn(this, SLOT(pass()), actionCollection());
     m_passMoveAction->setText(i18nc("@action:inmenu Move", "Pass Move"));
-    m_passMoveAction->setShortcut(Qt::Key_P);
+    actionCollection()->setDefaultShortcut(m_passMoveAction,Qt::Key_P);
     m_hintAction = KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
 
     // View menu
-    m_moveNumbersAction = new KToggleAction(KIcon( QLatin1String( "lastmoves") ), i18nc("@action:inmenu View", "Show Move &Numbers" ), this);
-    m_moveNumbersAction->setShortcut(Qt::Key_N);
+    m_moveNumbersAction = new KToggleAction(QIcon::fromTheme( QStringLiteral( "lastmoves") ), i18nc("@action:inmenu View", "Show Move &Numbers" ), this);
+    actionCollection()->setDefaultShortcut(m_moveNumbersAction, Qt::Key_N);
     m_moveNumbersAction->setChecked(Preferences::showMoveNumbers());
-    connect(m_moveNumbersAction, SIGNAL(toggled(bool)), m_gameScene, SLOT(showMoveNumbers(bool)));
-    actionCollection()->addAction( QLatin1String( "move_numbers" ), m_moveNumbersAction);
+    connect(m_moveNumbersAction, &KToggleAction::toggled, m_gameScene, &GameScene::showMoveNumbers);
+    actionCollection()->addAction( QStringLiteral( "move_numbers" ), m_moveNumbersAction);
 
     // Settings menu
     KStandardAction::preferences(this, SLOT(showPreferences()), actionCollection());
@@ -445,31 +449,28 @@ void MainWindow::setupDockWindows()
 {
     // Setup dock
     m_setupDock = new QDockWidget(i18nc("@title:window", "Game Setup"), this);
-    m_setupDock->setObjectName( QLatin1String("setupDock" ));
+    m_setupDock->setObjectName( QStringLiteral("setupDock" ));
     m_setupDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
     m_setupWidget = new SetupWidget(m_game, this);
     m_setupDock->setWidget(m_setupWidget);
-    connect(m_setupWidget, SIGNAL(startClicked()), this, SLOT(startGame()));
-    //m_setupDock->toggleViewAction()->setText(i18nc("@title:window", "Game setup"));
-    //m_setupDock->toggleViewAction()->setShortcut(Qt::Key_S);
-    //actionCollection()->addAction( QLatin1String( "show_setup_panel" ), m_setupDock->toggleViewAction());
+    connect(m_setupWidget, &SetupWidget::startClicked, this, &MainWindow::startGame);
     addDockWidget(Qt::RightDockWidgetArea, m_setupDock);
 
     // Game dock
     m_gameDock = new QDockWidget(i18nc("@title:window", "Information"), this);
-    m_gameDock->setObjectName( QLatin1String("gameDock" ));
+    m_gameDock->setObjectName( QStringLiteral("gameDock" ));
     m_gameDock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
-    GameWidget *gameWidget = new GameWidget(m_game, this);
-    connect(gameWidget, SIGNAL(finishClicked()), this, SLOT(finishGame()));
+    auto gameWidget = new GameWidget(m_game, this);
+    connect(gameWidget, &GameWidget::finishClicked, this, &MainWindow::finishGame);
     m_gameDock->setWidget(gameWidget);
     m_gameDock->toggleViewAction()->setText(i18nc("@title:window", "Information"));
-    m_gameDock->toggleViewAction()->setShortcut(Qt::Key_I);
-    actionCollection()->addAction( QLatin1String( "show_game_panel" ), m_gameDock->toggleViewAction());
+    actionCollection()->setDefaultShortcut(m_gameDock->toggleViewAction(), Qt::Key_I);
+    actionCollection()->addAction( QStringLiteral( "show_game_panel" ), m_gameDock->toggleViewAction());
     addDockWidget(Qt::RightDockWidgetArea, m_gameDock);
 
     // Move history dock
     m_movesDock = new QDockWidget(i18nc("@title:window", "Moves"), this);
-    m_movesDock->setObjectName( QLatin1String("movesDock" ));
+    m_movesDock->setObjectName( QStringLiteral("movesDock" ));
     m_undoView = new QUndoView(m_game->undoStack());
     m_undoView->setEmptyLabel(i18n("No move"));
     m_undoView->setAlternatingRowColors(true);
@@ -478,19 +479,16 @@ void MainWindow::setupDockWindows()
     m_undoView->setSelectionMode(QAbstractItemView::NoSelection);
     m_movesDock->setWidget(m_undoView);
     m_movesDock->toggleViewAction()->setText(i18nc("@title:window", "Moves"));
-    m_movesDock->toggleViewAction()->setShortcut(Qt::Key_M);
-    actionCollection()->addAction( QLatin1String( "show_moves_panel" ), m_movesDock->toggleViewAction());
+    actionCollection()->setDefaultShortcut(m_movesDock->toggleViewAction(), Qt::Key_M);
+    actionCollection()->addAction( QStringLiteral( "show_moves_panel" ), m_movesDock->toggleViewAction());
     addDockWidget(Qt::RightDockWidgetArea, m_movesDock);
 
     m_errorDock = new QDockWidget(i18nc("@title:window", "Error"), this);
-    m_errorDock->setObjectName( QLatin1String("errorDock" ));
+    m_errorDock->setObjectName( QStringLiteral("errorDock" ));
     m_errorDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
-    ErrorWidget *errorWidget = new ErrorWidget(this);
-    connect(errorWidget, SIGNAL(configureClicked()), this, SLOT(showPreferences()));
+    auto errorWidget = new ErrorWidget(this);
+    connect(errorWidget, &ErrorWidget::configureClicked, this, &MainWindow::showPreferences);
     m_errorDock->setWidget(errorWidget);
-    //m_errorDock->toggleViewAction()->setText(i18nc("@title:window", "Error"));
-    //m_errorDock->toggleViewAction()->setShortcut(Qt::Key_E);
-    //actionCollection()->addAction( QLatin1String( "show_error_panel" ), m_errorDock->toggleViewAction());
     addDockWidget(Qt::BottomDockWidgetArea, m_errorDock);
 }
 
@@ -501,5 +499,3 @@ bool MainWindow::isBackendWorking()
 }
 
 } // End of namespace Kigo
-
-#include "moc_mainwindow.cpp"
